@@ -13,7 +13,7 @@ from simpleloggerplus import simpleloggerplus as log
 from cryptdomainmgr.modules.common.cdmfilehelper import makeDir
 import time
 
-defaultCertConfig = {'keysize': 4096, 'extraflags': '', 'caa': {'url': 'letsencrypt.org', 'flag': '0', 'tag': 'issue'}}
+defaultConfig = {'keysize': 4096, 'extraflags': '', 'caa': {'url': 'letsencrypt.org', 'flag': '0', 'tag': 'issue'}}
 
 def prepare(certConfig, certState, statedir, domainList, domainAccessTable): 
     if 'dehydrated' != certConfig['handler'].split('/')[0]:
@@ -28,7 +28,7 @@ def prepare(certConfig, certState, statedir, domainList, domainAccessTable):
         extraFlags = certConfig['extraflags']
     extraFlags = [e if '-' == e[0] else '--' + e for e in extraFlags]
     if '--staging' in extraFlags:
-        ca = "https://acme-staging.api.letsencrypt.org/directory"
+        ca = "https://acme-staging-v02.api.letsencrypt.org/directory"
         extraFlags.remove('--staging')
         if 'staging' in extraFlags:
             extraFlags.remove('staging')
@@ -56,13 +56,17 @@ def prepare(certConfig, certState, statedir, domainList, domainAccessTable):
         args.extend(['-d', str(d)])
     log.debug(args)
     certState.setOpStateRunning()
-    try:
-        rv = check_output(args, env=dict(os.environ, DOMAINACCESSTABLE=domainAccessTable))
-        log.info(rv)
-    except CalledProcessError as e:
-        log.error(e.output)
-        time.sleep(1)
-        raise(e)
+
+    for i in range(10):
+        try:
+            rv = check_output(args, env=dict(os.environ, DOMAINACCESSTABLE=domainAccessTable))
+            log.info(rv)
+            break
+        except CalledProcessError as e:
+            log.error(e.output)
+            time.sleep(1)
+            if 9 == i:
+                raise(e)
 
     res = []
     rv = rv.splitlines()
